@@ -8,22 +8,22 @@ source conan/bin/activate
 if [[ "$(uname -s)" == 'Linux' ]]; then
     if [ "$CC" == "clang" ]; then
         # clang + Ubuntu don't like to run with UBSAN, but ASAN works
-        export CMAKE_OPTIONS="$CMAKE_OPTIONS -DCMAKE_CXX_FLAGS=\"-fsanitize=address\" -DCMAKE_C_FLAGS=\"-fsanitize=address\" -DCMAKE_EXE_LINKER_FLAGS=\"-fsanitize=address\" -DCMAKE_MODULE_LINKER_FLAGS=\"-fsanitize=address\""
+        export CMAKE_OPTIONS="$COMMON_CMAKE_OPTIONS"
     elif [ -n "$WITH_VALGRIND" ]; then
         export EXIV2_VALGRIND="valgrind --quiet"
     else
-        export CMAKE_OPTIONS="$CMAKE_OPTIONS -DEXIV2_TEAM_USE_SANITIZERS=ON"
+        export CMAKE_OPTIONS="$COMMON_CMAKE_OPTIONS -DEXIV2_TEAM_USE_SANITIZERS=OFF"
     fi
 else
-    export CMAKE_OPTIONS="$CMAKE_OPTIONS -DEXIV2_TEAM_USE_SANITIZERS=ON"
+    export CMAKE_OPTIONS="$COMMON_CMAKE_OPTIONS -DEXIV2_TEAM_USE_SANITIZERS=OFF"
 fi
-CMAKE_OPTIONS="$CMAKE_OPTIONS -DCMAKE_CXX_FLAGS=-Wno-deprecated"
+CMAKE_OPTIONS="$COMMON_CMAKE_OPTIONS -DCMAKE_CXX_FLAGS=-Wno-deprecated -DCMAKE_CXX_STANDARD=98 -DCMAKE_BUILD_TYPE=$BUILD_TYPE"
 
 mkdir build
 cd    build
 conan install .. -o webready=True --build missing
-cmake ${CMAKE_OPTIONS} -DEXIV2_TEAM_WARNINGS_AS_ERRORS=ON -DCMAKE_INSTALL_PREFIX=install ..
-make  -j 2
+cmake ${CMAKE_OPTIONS} ..
+make  -j
 make  tests
 make  install
 
