@@ -1,7 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2015 Andreas Huggel <ahuggel@gmx.net>
- *
+ * Copyright (C) 2004-2021 Exiv2 authors
  * This program is part of the Exiv2 distribution.
  *
  * This program is free software; you can redistribute it and/or
@@ -18,31 +17,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, 5th Floor, Boston, MA 02110-1301 USA.
  */
-/*!
-  @file    jpgimage.hpp
-  @brief   Class JpegImage to access JPEG images
-  @version $Rev: 3091 $
-  @author  Andreas Huggel (ahu)
-           <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
-  @author  Brad Schick (brad)
-           <a href="mailto:brad@robotbattle.com">brad@robotbattle.com</a>
-  @author  Volker Grabsch (vog)
-           <a href="mailto:vog@notjusthosting.com">vog@notjusthosting.com</a>
-  @author  Michael Ulbrich (mul)
-           <a href="mailto:mul@rentapacs.de">mul@rentapacs.de</a>
-  @date    15-Jan-05, brad: split out from image.cpp
- */
+ 
 #ifndef JPGIMAGE_HPP_
 #define JPGIMAGE_HPP_
 
 // *****************************************************************************
+#include "exiv2lib_export.h"
+
 // included header files
 #include "image.hpp"
-#include "basicio.hpp"
-#include "types.hpp"
-
-// + standard includes
-#include <string>
 
 // *****************************************************************************
 // namespace extensions
@@ -157,9 +140,9 @@ namespace Exiv2 {
           @brief Print out the structure of image file.
           @throw Error if reading of the file fails or the image data is
                 not valid (does not look like data of the specific image type).
-          @caution This function is not thread safe and intended for exiv2 -pS for debugging.
+          @warning This function is not thread safe and intended for exiv2 -pS for debugging.
          */
-        void printStructure(std::ostream& out, PrintStructureOption option);
+        void printStructure(std::ostream& out, PrintStructureOption option,int depth);
         //@}
 
     protected:
@@ -233,6 +216,7 @@ namespace Exiv2 {
         static const byte eoi_;                 //!< JPEG EOI marker
         static const byte app0_;                //!< JPEG APP0 marker
         static const byte app1_;                //!< JPEG APP1 marker
+        static const byte app2_;                //!< JPEG APP2 marker
         static const byte app13_;               //!< JPEG APP13 marker
         static const byte com_;                 //!< JPEG Comment marker
         static const byte sof0_;                //!< JPEG Start-Of-Frame marker
@@ -251,6 +235,7 @@ namespace Exiv2 {
         static const char exifId_[];            //!< Exif identifier
         static const char jfifId_[];            //!< JFIF identifier
         static const char xmpId_[];             //!< XMP packet identifier
+        static const char iccId_[];             //!< ICC profile identifier
 
     private:
         //! @name NOT implemented
@@ -272,7 +257,7 @@ namespace Exiv2 {
           @return 0 if successful;<BR>
                   4 if the image can not be written to.
          */
-        EXV_DLLLOCAL int initImage(const byte initData[], long dataSize);
+        int initImage(const byte initData[], long dataSize);
         /*!
           @brief Provides the main implementation of writeMetadata() by
                 writing all buffered metadata to the provided BasicIo.
@@ -280,7 +265,7 @@ namespace Exiv2 {
 
           @return 4 if opening or writing to the associated BasicIo fails
          */
-        EXV_DLLLOCAL void doWriteMetadata(BasicIo& oIo);
+        void doWriteMetadata(BasicIo& oIo);
         //@}
 
         //! @name Accessors
@@ -293,7 +278,7 @@ namespace Exiv2 {
           @return the next Jpeg segment marker if successful;<BR>
                  -1 if a maker was not found before EOF
          */
-        EXV_DLLLOCAL int advanceToMarker() const;
+        int advanceToMarker() const;
         //@}
 
     }; // class JpegBase
