@@ -1,16 +1,24 @@
 // ***************************************************************** -*- C++ -*-
 /*
-  Abstract : ExifData assignment and copy construction unit tests
-
-  File     : exifdata-test.cpp
-  Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
-  History  : 20-Feb-05, ahu: created
-
+ * Copyright (C) 2004-2021 Exiv2 authors
+ * This program is part of the Exiv2 distribution.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, 5th Floor, Boston, MA 02110-1301 USA.
  */
-// *****************************************************************************
-// included header files
-#include <exiv2/exiv2.hpp>
 
+#include <exiv2/exiv2.hpp>
 #include <iostream>
 #include <iomanip>
 #include <string>
@@ -26,6 +34,9 @@ int main(int argc, char* const argv[])
 try {
     Exiv2::XmpParser::initialize();
     ::atexit(Exiv2::XmpParser::terminate);
+#ifdef EXV_ENABLE_BMFF
+    Exiv2::enableBMFF();
+#endif
 
     if (argc != 2) {
         std::cout << "Usage: " << argv[0] << " file\n";
