@@ -1,7 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2015 Andreas Huggel <ahuggel@gmx.net>
- *
+ * Copyright (C) 2004-2021 Exiv2 authors
  * This program is part of the Exiv2 distribution.
  *
  * This program is free software; you can redistribute it and/or
@@ -20,15 +19,7 @@
  */
 /*
   File:      easyaccess.cpp
-  Version:   $Rev: 3777 $
-  Author(s): Carsten Pfeiffer <pfeiffer@kde.org>
-             Andreas Huggel (ahu) <ahuggel@gmx.net>
-  History:   28-Feb-09, gis: created
  */
-// *****************************************************************************
-#include "rcsid_int.hpp"
-EXIV2_RCSID("@(#) $Id: easyaccess.cpp 3777 2015-05-02 11:55:40Z ahuggel $")
-
 // *****************************************************************************
 // included header files
 #include "easyaccess.hpp"
@@ -112,24 +103,95 @@ namespace Exiv2 {
             "Exif.Casio2.ISOSpeed"
         };
 
+        struct SensKeyNameList {
+            int count;
+            const char* keys[3];
+        };
+
+        // covers Exif.Phot.SensitivityType values 1-7. Note that SOS, REI and
+        // ISO do differ in their meaning. Values coming first in a list (and
+        // existing as a tag) are picked up first and used as the "ISO" value.
+        static const SensKeyNameList sensitivityKey[] = {
+            { 1, { "Exif.Photo.StandardOutputSensitivity" }},
+            { 1, { "Exif.Photo.RecommendedExposureIndex" }},
+            { 1, { "Exif.Photo.ISOSpeed" }},
+            { 2, { "Exif.Photo.RecommendedExposureIndex", "Exif.Photo.StandardOutputSensitivity" }},
+            { 2, { "Exif.Photo.ISOSpeed", "Exif.Photo.StandardOutputSensitivity" }},
+            { 2, { "Exif.Photo.ISOSpeed", "Exif.Photo.RecommendedExposureIndex" }},
+            { 3, { "Exif.Photo.ISOSpeed", "Exif.Photo.RecommendedExposureIndex", "Exif.Photo.StandardOutputSensitivity" }}
+        };
+
+        static const char* sensitivityType[] = {
+            "Exif.Photo.SensitivityType"
+        };
+
         // Find the first ISO value which is not "0"
         const int cnt = EXV_COUNTOF(keys);
         ExifData::const_iterator md = ed.end();
+        long iso_val = -1;
         for (int idx = 0; idx < cnt; ) {
             md = findMetadatum(ed, keys + idx, cnt - idx);
             if (md == ed.end()) break;
             std::ostringstream os;
             md->write(os, &ed);
             bool ok = false;
-            long v = parseLong(os.str(), ok);
-            if (ok && v != 0) break;
+            iso_val = parseLong(os.str(), ok);
+            if (ok && iso_val > 0) break;
             while (strcmp(keys[idx++], md->key().c_str()) != 0 && idx < cnt) {}
             md = ed.end();
         }
 
+        // there is either a possible ISO "overflow" or no legacy
+        // ISO tag at all. Check for SensitivityType tag and the referenced
+        // ISO value (see EXIF 2.3 Annex G)
+        long iso_tmp_val = -1;
+        while (iso_tmp_val == -1 && (iso_val == 65535 || md == ed.end())) {
+            ExifData::const_iterator md_st = findMetadatum(ed, sensitivityType, 1);
+            // no SensitivityType? exit with existing data
+            if (md_st == ed.end())
+                break;
+            // otherwise pick up actual value and grab value accordingly
+            std::ostringstream os;
+            md_st->write(os, &ed);
+            bool ok = false;
+            const long st_val = parseLong(os.str(), ok);
+            // SensivityType out of range or cannot be parsed properly
+            if (!ok || st_val < 1 || st_val > 7)
+                break;
+            // pick up list of ISO tags, and check for at least one of
+            // them available.
+            const SensKeyNameList *sensKeys = &sensitivityKey[st_val - 1];
+            md_st = ed.end();
+            for (int idx = 0; idx < sensKeys->count; md_st = ed.end()) {
+                md_st = findMetadatum(ed, const_cast<const char**>(sensKeys->keys), sensKeys->count);
+                if (md_st == ed.end())
+                    break;
+                std::ostringstream os_iso;
+                md_st->write(os_iso, &ed);
+                ok = false;
+                iso_tmp_val = parseLong(os_iso.str(), ok);
+                // something wrong with the value
+                if (ok || iso_tmp_val > 0) {
+                    md = md_st;
+                    break;
+                }
+                while (strcmp(sensKeys->keys[idx++], md_st->key().c_str()) != 0 && idx < sensKeys->count) {}
+            }
+            break;
+        }
+
         return md;
     }
 
+    ExifData::const_iterator dateTimeOriginal(const ExifData& ed)
+    {
+        static const char* keys[] = {
+            "Exif.Photo.DateTimeOriginal",
+            "Exif.Image.DateTimeOriginal"
+        };
+        return findMetadatum(ed, keys, EXV_COUNTOF(keys));
+    }
+
     ExifData::const_iterator flashBias(const ExifData& ed)
     {
         static const char* keys[] = {
@@ -266,7 +328,7 @@ namespace Exiv2 {
     {
         static const char* keys[] = {
             // Exif.Canon.LensModel only reports focal length.
-            // Try Exif.CanonCs.LensType first. 
+            // Try Exif.CanonCs.LensType first.
             "Exif.CanonCs.LensType",
             "Exif.Photo.LensModel",
             "Exif.NikonLd1.LensIDNumber",
@@ -408,6 +470,51 @@ namespace Exiv2 {
         return findMetadatum(ed, keys, EXV_COUNTOF(keys));
     }
 
+    ExifData::const_iterator shutterSpeedValue(const ExifData& ed)
+    {
+        static const char* keys[] = {
+            "Exif.Photo.ShutterSpeedValue",
+            "Exif.Image.ShutterSpeedValue"
+        };
+        return findMetadatum(ed, keys, EXV_COUNTOF(keys));
+    }
+
+    ExifData::const_iterator apertureValue(const ExifData& ed)
+    {
+        static const char* keys[] = {
+            "Exif.Photo.ApertureValue",
+            "Exif.Image.ApertureValue"
+        };
+        return findMetadatum(ed, keys, EXV_COUNTOF(keys));
+    }
+
+    ExifData::const_iterator brightnessValue(const ExifData& ed)
+    {
+        static const char* keys[] = {
+            "Exif.Photo.BrightnessValue",
+            "Exif.Image.BrightnessValue"
+        };
+        return findMetadatum(ed, keys, EXV_COUNTOF(keys));
+    }
+
+    ExifData::const_iterator exposureBiasValue(const ExifData& ed)
+    {
+        static const char* keys[] = {
+            "Exif.Photo.ExposureBiasValue",
+            "Exif.Image.ExposureBiasValue"
+        };
+        return findMetadatum(ed, keys, EXV_COUNTOF(keys));
+    }
+
+    ExifData::const_iterator maxApertureValue(const ExifData& ed)
+    {
+        static const char* keys[] = {
+            "Exif.Photo.MaxApertureValue",
+            "Exif.Image.MaxApertureValue"
+        };
+        return findMetadatum(ed, keys, EXV_COUNTOF(keys));
+    }
+
     ExifData::const_iterator subjectDistance(const ExifData& ed)
     {
         static const char* keys[] = {
@@ -429,6 +536,24 @@ namespace Exiv2 {
         return findMetadatum(ed, keys, EXV_COUNTOF(keys));
     }
 
+    ExifData::const_iterator lightSource(const ExifData& ed)
+    {
+        static const char* keys[] = {
+            "Exif.Photo.LightSource",
+            "Exif.Image.LightSource"
+        };
+        return findMetadatum(ed, keys, EXV_COUNTOF(keys));
+    }
+
+    ExifData::const_iterator flash(const ExifData& ed)
+    {
+        static const char* keys[] = {
+            "Exif.Photo.Flash",
+            "Exif.Image.Flash"
+        };
+        return findMetadatum(ed, keys, EXV_COUNTOF(keys));
+    }
+
     ExifData::const_iterator serialNumber(const ExifData& ed)
     {
         static const char* keys[] = {
@@ -459,6 +584,42 @@ namespace Exiv2 {
         return findMetadatum(ed, keys, EXV_COUNTOF(keys));
     }
 
+    ExifData::const_iterator subjectArea(const ExifData& ed)
+    {
+        static const char* keys[] = {
+            "Exif.Photo.SubjectArea",
+            "Exif.Image.SubjectLocation"
+        };
+        return findMetadatum(ed, keys, EXV_COUNTOF(keys));
+    }
+
+    ExifData::const_iterator flashEnergy(const ExifData& ed)
+    {
+        static const char* keys[] = {
+            "Exif.Photo.FlashEnergy",
+            "Exif.Image.FlashEnergy"
+        };
+        return findMetadatum(ed, keys, EXV_COUNTOF(keys));
+    }
+
+    ExifData::const_iterator exposureIndex(const ExifData& ed)
+    {
+        static const char* keys[] = {
+            "Exif.Photo.ExposureIndex",
+            "Exif.Image.ExposureIndex"
+        };
+        return findMetadatum(ed, keys, EXV_COUNTOF(keys));
+    }
+
+    ExifData::const_iterator sensingMethod(const ExifData& ed)
+    {
+        static const char* keys[] = {
+            "Exif.Photo.SensingMethod",
+            "Exif.Image.SensingMethod"
+        };
+        return findMetadatum(ed, keys, EXV_COUNTOF(keys));
+    }
+
     ExifData::const_iterator afPoint(const ExifData& ed)
     {
         static const char* keys[] = {
