@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2018 Exiv2 authors
+ * Copyright (C) 2004-2021 Exiv2 authors
  * This program is part of the Exiv2 distribution.
  *
  * This program is free software; you can redistribute it and/or
@@ -17,12 +17,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, 5th Floor, Boston, MA 02110-1301 USA.
  */
-/*
-  File:    pgfimage.cpp
-  Author(s): Gilles Caulier (cgilles) <caulier dot gilles at gmail dot com>
-  History: 16-Jun-09, gc: submitted
-  Credits: See header file
- */
 // *****************************************************************************
 // included header files
 #include "config.h"
@@ -72,7 +66,7 @@ namespace Exiv2 {
 
     static uint32_t byteSwap_(Exiv2::DataBuf& buf,size_t offset,bool bSwap)
     {
-        uint32_t v;
+        uint32_t v = 0;
         char*    p = (char*) &v;
         int      i;
         for ( i = 0 ; i < 4 ; i++ ) p[i] = buf.pData_[offset+i];
@@ -195,7 +189,7 @@ namespace Exiv2 {
 
         readPgfHeaderSize(*io_);
 
-        int w, h;
+        int w = 0, h = 0;
         DataBuf header      = readPgfHeaderStructure(*io_, w, h);
 
         Image::AutoPtr img  = ImageFactory::create(ImageType::png);
