@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2018 Exiv2 authors
+ * Copyright (C) 2004-2021 Exiv2 authors
  * This program is part of the Exiv2 distribution.
  *
  * This program is free software; you can redistribute it and/or
@@ -17,13 +17,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, 5th Floor, Boston, MA 02110-1301 USA.
  */
-/*!
-  @file    utilsvideo.hpp
-  @brief   An Image subclass to support RIFF video files
-           Mahesh Hegde 2014
-           <b href="mailto:maheshmhegade@gmail.com">maheshmhegade@gmail.com</b>
-  @date    16-Aug-14, AB: created
- */
 // *****************************************************************************
 
 #include "config.h"
